@@ -5,7 +5,7 @@ use utf8;
 
 package Art::World {
 
-  our $VERSION = '0.17_01';
+  our $VERSION = '0.17_02';
 
   use Zydeco authority => 'cpan:SMONFF', version   => $VERSION;
 
@@ -40,10 +40,16 @@ package Art::World {
     method belongs_to {
       return $self->owner;
     }
-    # If an Agent work is  artworks collected, it's reputation should go up
-    requires creator;
-    method {
+  }
 
+  # I guess it can be consummed by pretty much everything. Like idk, a place
+  # have a fame and an artwork too. But it was supposed to be more like an Agent
+  # thing in the beginning
+  role Fame {
+    has reputation ( is => rw, type => PositiveOrZeroNum );
+    # TODO If an Agent work is  collected, it's reputation should go up
+    method bump_fame( Num $gain = 1 ) {
+      $self->reputation( $self->reputation + $gain );
     }
   }
 
@@ -91,7 +97,7 @@ package Art::World {
     has idea!, process, file!, discourse, time, project;
   }
 
-  class Event {
+  class Event with Fame {
     has place;
     has datetime;
     # "guests"
@@ -111,7 +117,7 @@ package Art::World {
     };
 
 
-    class Place with Space {
+    class Place with Space, Fame {
       class Institution {
         class School {
           has student;
@@ -141,11 +147,10 @@ package Art::World {
     class Website;
   }
 
-  class Agent with Active {
+  class Agent with Active, Fame {
     # Should be required but will be moved to the Crudable area
     has id         ( type => Int );
     has name!       ( type => Str );
-    has reputation ( type => Int );
 
     class Artist {
 
@@ -205,7 +210,7 @@ package Art::World {
   }
 
 
-  class Work {
+  class Work with Fame {
 
     has creation_date;
     has creator (
@@ -223,7 +228,7 @@ package Art::World {
 
     class Book;
 
-    class Exhibition;
+    class Exhibition extends Event;
   }
 }
 
@@ -278,6 +283,17 @@ If it's collectionable, it can go to a C<Collector> collection or in a C<Museum>
 
 Role for L<C<Places>|Art::World/"Place"> that display some  L<C<Artworks>|Art::World/"Artwork">.
 
+=head2 Fame
+
+C<Fame> role provide ways to control the knowledge and reputation that various
+C<Agents>, C<Places> or C<Works> have.
+
+It has an handy C<bump_fame()> method that self-bump the fame count. It can be
+passed a positive C<Num>, a negative C<Num> (so that the fame will get lower)
+and even no parameter, in that case it will just add 1.
+
+
+
 =head2 Market
 
 It is all about offer and demand. Involve a price but should involve more money
